@@ -1,4 +1,4 @@
-#[derive(Clone, Copy, PartialEq, Eq)]
+#[derive(Clone, Copy, Debug, PartialEq, Eq)]
 pub enum Dtype {
     F64,
     F32,
@@ -8,6 +8,7 @@ pub enum Dtype {
     NaiveDateTime,
     NaiveDate,
     NaiveTime,
+    Duration,
 }
 
 impl Dtype {
@@ -31,8 +32,12 @@ impl Dtype {
 
     pub fn is_chrono(&self) -> bool {
         match self {
-            Dtype::NaiveDateTime | Dtype::NaiveDate | Dtype::NaiveTime => true,
+            Dtype::NaiveDateTime | Dtype::NaiveDate | Dtype::NaiveTime | Dtype::Duration => true,
             _ => false,
         }
     }
+
+    pub fn is_string(&self) -> bool {
+        self == &Dtype::String
+    }
 }
